@@ -7,9 +7,9 @@
 setMethod ("has.RGB" , "SpatRaster",
 	function(x, strict=TRUE) {
 		if (strict) {
-			x@ptr$rgbtype == "rgb"
+			x@pntr$rgbtype == "rgb"
 		} else {
-			x@ptr$rgbtype != ""
+			x@pntr$rgbtype != ""
 		}
 	}
 )
@@ -18,7 +18,7 @@ setMethod ("has.RGB" , "SpatRaster",
 setMethod("set.RGB", signature(x="SpatRaster"),
 	function(x, value=1:3, type="rgb") {
 		if (is.null(value[1]) || is.na(value[1]) || any(value < 1)) {
-			x@ptr$removeRGB()
+			x@pntr$removeRGB()
 		} else {
 			if (inherits(value, "character")) {
 				i <- match(value, names(x))
@@ -30,9 +30,9 @@ setMethod("set.RGB", signature(x="SpatRaster"),
 				error("set.RGB", "value(s) are not value layer numbers")			
 			}
 			if (length(value) == 3) {
-				x@ptr$setRGB(value[1]-1, value[2]-1, value[3]-1, -99, type)
+				x@pntr$setRGB(value[1]-1, value[2]-1, value[3]-1, -99, type)
 			} else if (length(value) == 4) {
-				x@ptr$setRGB(value[1]-1, value[2]-1, value[3]-1, value[4]-1, type)
+				x@pntr$setRGB(value[1]-1, value[2]-1, value[3]-1, value[4]-1, type)
 			} else {
 				error("set.RGB", "value must have length 3 or 4")
 			}
@@ -44,7 +44,7 @@ setMethod("set.RGB", signature(x="SpatRaster"),
 
 setMethod("RGB<-", signature(x="SpatRaster"),
 	function(x, ..., type="rgb", value) {
-		x@ptr <- x@ptr$deepcopy()
+		x@pntr <- x@pntr$deepcopy()
 		set.RGB(x, value, type)
 		x
 	}
@@ -56,8 +56,8 @@ setMethod("RGB", signature(x="SpatRaster"),
 			RGB(x, type=type) <- value
 			return(x)
 		} else {
-			if (x@ptr$rgb) {
-				x@ptr$getRGB() + 1
+			if (x@pntr$rgb) {
+				x@pntr$getRGB() + 1
 			} else {
 				return(NULL)
 			}
@@ -148,7 +148,7 @@ rgb2col <- function(x, value, stretch=NULL, grays=FALSE, NAzero=FALSE, filename=
 
 	if (grays) {
 		opt <- spatOptions(filename, overwrite, ...)
-		x@ptr <- x@ptr$rgb2col(0, 1, 2, opt)
+		x@pntr <- x@pntr$rgb2col(0, 1, 2, opt)
 		return(messages(x, "colorize"))
 	}
 
@@ -207,17 +207,17 @@ setMethod("colorize", signature(x="SpatRaster"),
 		to <- tolower(to)
 		if (to %in% c("hsi", "hsl", "hsv")) {
 			opt <- spatOptions(filename, overwrite, ...)
-			x@ptr <- x@ptr$rgb2hsx(to, opt)
+			x@pntr <- x@pntr$rgb2hsx(to, opt)
 		} else if (to == "rgb") {
 			if (nlyr(x) == 1) {
 				return(terra_col2rgb(x, alpha=alpha, filename=filename, overwrite=overwrite, ...))
 			} else {
 				opt <- spatOptions(filename, overwrite, ...)
-				x@ptr <- x@ptr$hsx2rgb(opt)
+				x@pntr <- x@pntr$hsx2rgb(opt)
 			}
 		} else if (to == "hsl") {
 			opt <- spatOptions(filename, overwrite, ...)
-			x@ptr <- x@ptr$hsx2rgb(to, opt)
+			x@pntr <- x@pntr$hsx2rgb(to, opt)
 		} else if (to == "col") {
 			return(rgb2col(x, stretch=stretch, grays=grays, NAzero=NAzero, filename=filename, overwrite=overwrite, ...))
 		} else {
