@@ -5,7 +5,7 @@
 
 setMethod("ext", signature(x="SpatExtent"),
 	function(x){
-		x@ptr <- x@ptr$deepcopy()
+		x@pntr <- x@pntr$deepcopy()
 		x
 	}
 )
@@ -13,7 +13,7 @@ setMethod("ext", signature(x="SpatExtent"),
 setMethod("ext", signature(x="SpatRasterCollection"),
 	function(x){
 		e <- methods::new("SpatExtent")
-		e@ptr <- x@ptr$extent()
+		e@pntr <- x@pntr$extent()
 		e
 	}
 )
@@ -31,7 +31,7 @@ setMethod("ext", signature(x="sf"),
 setMethod("ext", signature(x="missing"),
 	function(x){
 		e <- methods::new("SpatExtent")
-		e@ptr <- SpatExtent$new()
+		e@pntr <- SpatExtent$new()
 		e
 	}
 )
@@ -47,11 +47,11 @@ setMethod("ext", signature(x="numeric"),
 		names(x) <- NULL
 		e <- methods::new("SpatExtent")
 		if (xy) {
-			e@ptr <- SpatExtent$new(x[1], x[3], x[2], x[4])
+			e@pntr <- SpatExtent$new(x[1], x[3], x[2], x[4])
 		} else {
-			e@ptr <- SpatExtent$new(x[1], x[2], x[3], x[4])
+			e@pntr <- SpatExtent$new(x[1], x[2], x[3], x[4])
 		}
-		if (!e@ptr$valid) {
+		if (!e@pntr$valid) {
 			error("ext", "invalid extent")
 		}
 		e
@@ -88,7 +88,7 @@ setMethod("ext", signature(x="SpatRaster"),
 			ext(range(xFromCell(x, cells)) + dx, range(yFromCell(x, cells)) + dy)
 		} else {
 			e <- methods::new("SpatExtent")
-			e@ptr <- x@ptr$extent
+			e@pntr <- x@pntr$extent
 			return(e)
 		}
 	}
@@ -99,7 +99,7 @@ setMethod("ext", signature(x="SpatRaster"),
 setMethod("ext", signature(x="SpatRasterDataset"),
 	function(x){
 		e <- methods::new("SpatExtent")
-		e@ptr <- x@ptr$ext()
+		e@pntr <- x@pntr$ext()
 		return(e)
 	}
 )
@@ -108,7 +108,7 @@ setMethod("ext", signature(x="SpatRasterDataset"),
 
 setMethod("ext<-", signature("SpatRaster", "SpatExtent"),
 	function(x, value) {
-		x@ptr$extent <- value@ptr
+		x@pntr$extent <- value@pntr
 		messages(x, "ext<-")
 	}
 )
@@ -117,8 +117,8 @@ setMethod("ext<-", signature("SpatRaster", "SpatExtent"),
 setMethod("ext<-", signature("SpatRaster", "numeric"),
 	function(x, value) {
 		e <- ext(value)
-		x@ptr <- x@ptr$deepcopy()
-		x@ptr$extent <- e@ptr
+		x@pntr <- x@pntr$deepcopy()
+		x@pntr$extent <- e@pntr
 		messages(x, "ext<-")
 	}
 )
@@ -126,7 +126,7 @@ setMethod("ext<-", signature("SpatRaster", "numeric"),
 setMethod("set.ext", signature("SpatRaster"),
 	function(x, value) {
 		e <- ext(value)
-		x@ptr$extent <- e@ptr
+		x@pntr$extent <- e@pntr
 		messages(x, "set_ext")
 		invisible(TRUE)
 	}
@@ -136,15 +136,23 @@ setMethod("set.ext", signature("SpatRaster"),
 setMethod("ext", signature(x="SpatVector"),
 	function(x) {
 		e <- methods::new("SpatExtent")
-		e@ptr <- x@ptr$extent()
+		e@pntr <- x@pntr$extent()
 		e
 	}
 )
 
+setMethod("ext", signature(x="SpatVectorCollection"),
+	function(x) {
+		e <- sapply(x, function(e) as.vector(ext(e)))
+		ext(min(e[1,]), max(e[2,]), min(e[3,]), max(e[4,]))
+	}
+)
+
+
 setMethod("ext", signature(x="SpatVectorProxy"),
 	function(x) {
 		e <- methods::new("SpatExtent")
-		e@ptr <- x@ptr$v$extent()
+		e@pntr <- x@pntr$v$extent()
 		e
 	}
 )
@@ -172,22 +180,22 @@ setMethod("ext", signature(x="Spatial"),
 
 setMethod("xmin", signature(x="SpatExtent"),
 	function(x){
-		x@ptr$vector[1]
+		x@pntr$vector[1]
 	}
 )
 setMethod("xmax", signature(x="SpatExtent"),
 	function(x){
-		x@ptr$vector[2]
+		x@pntr$vector[2]
 	}
 )
 setMethod("ymin", signature(x="SpatExtent"),
 	function(x){
-		x@ptr$vector[3]
+		x@pntr$vector[3]
 	}
 )
 setMethod("ymax", signature(x="SpatExtent"),
 	function(x){
-		x@ptr$vector[4]
+		x@pntr$vector[4]
 	}
 )
 
@@ -248,7 +256,7 @@ setMethod("xmin<-", signature("SpatRaster", "numeric"),
 	function(x, value){
 		v <- as.vector(ext(x))
 		v[1] <- value
-		x@ptr <- x@ptr$deepcopy()
+		x@pntr <- x@pntr$deepcopy()
 		ext(x) <- ext(v)
 		x
 	}
@@ -259,7 +267,7 @@ setMethod("xmax<-", signature("SpatRaster", "numeric"),
 	function(x, value){
 		v <- as.vector(ext(x))
 		v[2] <- value
-		x@ptr <- x@ptr$deepcopy()
+		x@pntr <- x@pntr$deepcopy()
 		ext(x) <- ext(v)
 		x
 	}
@@ -268,7 +276,7 @@ setMethod("ymin<-", signature("SpatRaster", "numeric"),
 	function(x, value){
 		v <- as.vector(ext(x))
 		v[3] <- value
-		x@ptr <- x@ptr$deepcopy()
+		x@pntr <- x@pntr$deepcopy()
 		ext(x) <- ext(v)
 		x
 	}
@@ -278,7 +286,7 @@ setMethod("ymax<-", signature("SpatRaster", "numeric"),
 	function(x, value){
 		v <- as.vector(ext(x))
 		v[4] <- value
-		x@ptr <- x@ptr$deepcopy()
+		x@pntr <- x@pntr$deepcopy()
 		ext(x) <- ext(v)
 		x
 	}
@@ -351,14 +359,14 @@ setReplaceMethod("[", c("SpatExtent", "numeric", "missing"),
 
 setMethod("is.valid", signature(x="SpatExtent"),
 	function(x) {
-		x@ptr$valid
-		#x@ptr$valid_notempty
+		x@pntr$valid
+		#x@pntr$valid_notempty
 	}
 )
 
 
 setMethod("is.empty", signature(x="SpatExtent"),
 	function(x) {
-		x@ptr$empty
+		x@pntr$empty
 	}
 )
