@@ -10,6 +10,13 @@ setMethod("is.rotated", signature(x="SpatRaster"),
 )
 
 
+setMethod("is.flipped", signature(x="SpatRaster"),
+	function(x)  {
+		x@pntr$is_flipped()
+	}
+)
+
+
 setMethod("rangeFill", signature(x="SpatRaster"),
 	function(x, limit, circular=FALSE, filename="", ...) {
 		opt <- spatOptions(filename, ...)
@@ -666,11 +673,7 @@ setMethod("project", signature(x="SpatRaster"),
 				method <- "bilinear"
 			}
 		} else {
-			method <- method[1]
-		}
-		if (method == "ngb") {
-			method <- "near"
-			warn("project", "argument 'method=ngb' is deprecated, it should be 'method=near'")
+			method <- match.arg(tolower(method[1]), c("near", "bilinear", "cubic", "cubicspline", "lanczos", "average", "sum", "mode", "min", "q1", "median", "q3", "max", "rms"))			
 		}
 		opt <- spatOptions(filename, threads=threads, ...)
 
@@ -817,14 +820,16 @@ setMethod("rectify", signature(x="SpatRaster"),
 )
 
 setMethod("resample", signature(x="SpatRaster", y="SpatRaster"),
-	function(x, y, method, threads=FALSE, filename="", ...)  {
+	function(x, y, method, threads=FALSE, by_util=FALSE, filename="", ...)  {
 
 		if (missing(method)) {
-			method <- ifelse(is.factor(x)[1], "near", "bilinear")
-		}
-		if (method == "ngb") {
-			method <- "near"
-			warn("resample", "argument 'method=ngb' is deprecated, it should be 'method=near'")
+			if (is.factor(x)[1] || isTRUE(x@pntr$rgb)) {
+				method <- "near"
+			} else {
+				method <- "bilinear"
+			}
+		} else {
+			method <- match.arg(tolower(method[1]), c("near", "bilinear", "cubic", "cubicspline", "lanczos", "average", "sum", "mode", "min", "q1", "median", "q3", "max", "rms"))			
 		}
 		xcrs = crs(x)
 		ycrs = crs(y)
@@ -835,11 +840,12 @@ setMethod("resample", signature(x="SpatRaster", y="SpatRaster"),
 			crs(y) <- xcrs
 		}
 		opt <- spatOptions(filename, threads=threads, ...)
-#		if (gdal) {
+
+		if (by_util) {
+			x@pntr <- x@pntr$warp_by_util(y@pntr, "", method, FALSE, FALSE, TRUE, opt)
+		} else {
 			x@pntr <- x@pntr$warp(y@pntr, "", method, FALSE, FALSE, TRUE, opt)
-#		} else {
-#			x@pntr <- x@pntr$resample(y@pntr, method, FALSE, TRUE, opt)
-#		}
+		}
 		messages(x, "resample")
 	}
 )
