@@ -43,14 +43,14 @@ setMethod("dots", signature(x="SpatVector"),
 #	cols <- out$cols
 #	if (is.null(cols)) cols = rep("black", n)
 
-#	g <- lapply(x@ptr$linesList(), function(i) { names(i)=c("x", "y"); i } )
+#	g <- lapply(x@pntr$linesList(), function(i) { names(i)=c("x", "y"); i } )
 
 #	g <- geom(x, df=TRUE)
 #	g <- split(g, g[,1])
 #	g <- lapply(g, function(x) split(x[,3:4], x[,2]))
 #	n <- length(g)
 
-	g <- x@ptr$linesList()
+	g <- x@pntr$linesList()
 	lty <- rep_len(lty, n)
 	lwd <- rep_len(lwd, n)
 	for (i in 1:n) {
@@ -119,7 +119,7 @@ setMethod("dots", signature(x="SpatVector"),
 #				# g[[i]][[1]] <- a
 #			}
 
-	g <- x@ptr$polygonsList()
+	g <- x@pntr$polygonsList()
 	if (is.null(out$leg$density)) {
 		for (i in seq_along(g)) {
 			for (j in seq_along(g[[i]])) {
@@ -437,7 +437,7 @@ setMethod("dots", signature(x="SpatVector"),
 	xlim=NULL, ylim=NULL, colNA=NA, alpha=NULL, axes=TRUE, buffer=TRUE, background=NULL,
 	pax=list(), plg=list(), ext=NULL, grid=FALSE, las=0, sort=TRUE, decreasing=FALSE, values=NULL,
 	box=TRUE, xlab="", ylab="", cex.lab=0.8, line.lab=1.5, yaxs="i", xaxs="i", main="", cex.main=1.2, line.main=0.5, font.main=graphics::par()$font.main, col.main = graphics::par()$col.main, 
-	density=NULL, angle=45, border="black", dig.lab=3, cex=1, clip=TRUE, leg_i=1, asp=NULL, ...) {
+	density=NULL, angle=45, border="black", dig.lab=3, cex=1, clip=TRUE, leg_i=1, asp=NULL, xpd=NULL, ...) {
 
 	out <- list()
 	out$blank <- FALSE
@@ -483,7 +483,9 @@ setMethod("dots", signature(x="SpatVector"),
 			stopifnot(length(ylim) == 2)
 			out$lim[3:4] <- sort(ylim)
 		}
-	} 
+	} else if ((!add) && is.null(xpd)) {
+		xpd <- TRUE
+	}
 	out$ngeom <- nrow(x)
 	out$clip <- isTRUE(clip)
 
@@ -613,7 +615,8 @@ setMethod("dots", signature(x="SpatVector"),
 				cols <- "black"
 			}
 		} else {
-			cols <- rev(grDevices::rainbow(100, start=.1, end=0.9))
+			cols <- .default.pal()
+#			cols <- rev(grDevices::rainbow(100, start=.1, end=0.9))
 		}
 	}
 	if (!is.null(alpha)) {
@@ -650,7 +653,7 @@ setMethod("dots", signature(x="SpatVector"),
 		}
 	}
 
-	.plot.vect.map(x, out, ...)
+	.plot.vect.map(x, out, xpd=xpd, ...)
 }
 
 
@@ -784,3 +787,15 @@ setMethod("plot", signature(x="SpatVectorCollection", y="missing"),
 	}
 )
 
+setMethod("plot", signature(x="SpatVectorCollection", y="numeric"),
+	function(x, y, main, mar=NULL, ext=NULL, ...) {
+		y <- round(y)
+		if ((y > 0) && (y <= length(x))) {
+			if (is.null(ext)) ext <- ext(x)
+			plot(x[y], main=main, mar=mar, ext=ext, ...)
+		} else {
+			error("plot", "y should be between 1 and length(x)")
+		}
+	}
+)
+
